Changelog for kubepy
=================

1.5.0 (2017-01-13)
------------------

- Allowed --directory <path> to be used multiple times to override definitions.
- Added --host-volume <name>=<path> to add host volume to pod definitions.


1.4.0 (2016-12-07)
------------------

- Add pod as one time job support.
- Don't require app label in jobs.


1.3.0 (2016-11-25)
------------------

- Handle exceeded deadline in job applier.


1.2.0 (2016-10-21)
------------------

- Allow to replace deployments instead of updating them.

1.1 (2016-10-06)
----------------

- Changes tracking started.
